==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/todolist/api/ITodoListAsync.java <==
package net.bluemind.todolist.api;
import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.BMAsyncApi;

@BMAsyncApi(net.bluemind.todolist.api.ITodoList.class)
public interface ITodoListAsync  {

	void getVersion(
	               AsyncHandler<Long> handler);

	void filteredChangesetById(java.lang.Long since , net.bluemind.core.container.model.ItemFlagFilter arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<net.bluemind.core.container.model.ItemVersion>> handler);

	void itemChangelog(java.lang.String uid , java.lang.Long arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ItemChangelog> handler);

	void changeset(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.String>> handler);

	void changesetById(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.Long>> handler);

	void containerChangelog(java.lang.Long arg0 , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangelog> handler);

	void allIds(java.lang.String filter , java.lang.Long knownContainerVersion , java.lang.Integer limit , java.lang.Integer offset , 
	               AsyncHandler<net.bluemind.core.api.ListResult<java.lang.Long>> handler);

	void count(net.bluemind.core.container.model.ItemFlagFilter arg0 , 
	               AsyncHandler<net.bluemind.core.container.api.Count> handler);

	void multipleGetById(java.util.List<java.lang.Long> arg0 , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void getCompleteById(long id , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>> handler);

	void multipleDeleteById(java.util.List<java.lang.Long> arg0 , 
	               AsyncHandler<Void> handler);

	void updateById(long id , net.bluemind.todolist.api.VTodo arg1 , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void deleteById(long id , 
	               AsyncHandler<Void> handler);

	void createById(long id , net.bluemind.todolist.api.VTodo arg1 , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void sortedIds(net.bluemind.core.container.model.SortDescriptor arg0 , 
	               AsyncHandler<java.util.List<java.lang.Long>> handler);

	void allUids(
	               AsyncHandler<java.util.List<java.lang.String>> handler);

	void update(java.lang.String uid , net.bluemind.todolist.api.VTodo todo , 
	               AsyncHandler<Void> handler);

	void updates(net.bluemind.todolist.api.VTodoChanges changes , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerUpdatesResult> handler);

	void delete(java.lang.String uid , 
	               AsyncHandler<Void> handler);

	void search(net.bluemind.todolist.api.VTodoQuery query , 
	               AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void create(java.lang.String uid , net.bluemind.todolist.api.VTodo todo , 
	               AsyncHandler<Void> handler);

	void copy(java.util.List<java.lang.String> uids , java.lang.String destContainerUid , 
	               AsyncHandler<Void> handler);

	void all(
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void move(java.util.List<java.lang.String> uids , java.lang.String destContainerUid , 
	               AsyncHandler<Void> handler);

	void multipleGet(java.util.List<java.lang.String> uids , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void sync(java.lang.Long since , net.bluemind.todolist.api.VTodoChanges changes , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.String>> handler);

	void getComplete(java.lang.String uid , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>> handler);

	void reset(
	               AsyncHandler<Void> handler);

}

==> net.bluemind.p2.platform-5.5.3184.zip: net/bluemind/todolist/api/ITodoListAsync.java <==
package net.bluemind.todolist.api;
import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.BMAsyncApi;

@BMAsyncApi(net.bluemind.todolist.api.ITodoList.class)
public interface ITodoListAsync  {

	void all(
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void allUids(
	               AsyncHandler<java.util.List<java.lang.String>> handler);

	void changeset(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.String>> handler);

	void changesetById(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.Long>> handler);

	void copy(java.util.List<java.lang.String> uids , java.lang.String destContainerUid , 
	               AsyncHandler<Void> handler);

	void count(net.bluemind.core.container.model.ItemFlagFilter arg0 , 
	               AsyncHandler<net.bluemind.core.container.api.Count> handler);

	void create(java.lang.String uid , net.bluemind.todolist.api.VTodo todo , 
	               AsyncHandler<Void> handler);

	void createById(long id , net.bluemind.todolist.api.VTodo arg1 , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void delete(java.lang.String uid , 
	               AsyncHandler<Void> handler);

	void deleteById(long id , 
	               AsyncHandler<Void> handler);

	void filteredChangesetById(java.lang.Long since , net.bluemind.core.container.model.ItemFlagFilter arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<net.bluemind.core.container.model.ItemVersion>> handler);

	void getByIcsUid(java.lang.String uid , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void getComplete(java.lang.String uid , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>> handler);

	void getCompleteById(long id , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>> handler);

	void getVersion(
	               AsyncHandler<Long> handler);

	void itemChangelog(java.lang.String uid , java.lang.Long arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ItemChangelog> handler);

	void move(java.util.List<java.lang.String> uids , java.lang.String destContainerUid , 
	               AsyncHandler<Void> handler);

	void multipleDeleteById(java.util.List<java.lang.Long> arg0 , java.lang.Boolean bypassDeletedItems , 
	               AsyncHandler<Void> handler);

	void multipleGet(java.util.List<java.lang.String> uids , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void multipleGetById(java.util.List<java.lang.Long> arg0 , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void multipleGetByRange(net.bluemind.todolist.api.VTodoRange range , 
	               AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void multipleGetWithOffset(java.lang.Integer from , java.lang.Integer size , 
	               AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void reset(
	               AsyncHandler<Void> handler);

	void search(net.bluemind.todolist.api.VTodoQuery query , 
	               AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.core.container.model.ItemValue<net.bluemind.todolist.api.VTodo>>> handler);

	void sortedIds(net.bluemind.core.container.model.SortDescriptor arg0 , 
	               AsyncHandler<java.util.List<java.lang.Long>> handler);

	void sortedUids(net.bluemind.core.container.model.SortDescriptor arg0 , 
	               AsyncHandler<java.util.List<java.lang.String>> handler);

	void sync(java.lang.Long since , net.bluemind.todolist.api.VTodoChanges changes , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.String>> handler);

	void update(java.lang.String uid , net.bluemind.todolist.api.VTodo todo , 
	               AsyncHandler<Void> handler);

	void updateById(long id , net.bluemind.todolist.api.VTodo arg1 , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void updates(net.bluemind.todolist.api.VTodoChanges changes , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerUpdatesResult> handler);

}
